@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -38,6 +38,10 @@ COPYING distributed with the source files.
 #include "utils/tree_path_handle.h"
 #include "addressbook_icons.h"
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
 #ifdef ENABLE_NLS
 #include <libintl.h>
 #endif
