@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -35,6 +35,10 @@ COPYING distributed with the source files.
 #include "utils/mutex.h"
 #include "utils/shared_handle.h"
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
 #ifdef HAVE_STRINGSTREAM
 #include <sstream>
 #else
@@ -296,28 +300,31 @@ void EfaxController::sendfax_slot(void) {
 
 std::pair<const char*, char* const*> EfaxController::get_gs_parms(const std::string& basename) {
 
-  // lock the Prog_config object to stop it being modified in the intial (GUI) thread
-  // while we are accessing it here
-  Thread::Mutex::Lock lock(*prog_config.mutex_p);
-
   std::vector<std::string> parms;
-  std::string temp;
-  parms.push_back("gs");
-  parms.push_back("-q");
-  parms.push_back("-sDEVICE=tiffg3");
-  temp = "-r";
-  temp += prog_config.resolution;
-  parms.push_back(temp);
-  parms.push_back("-dNOPAUSE");
-  parms.push_back("-dSAFER");
-  temp = "-sOutputFile=";
-  temp += basename + ".%03d";
-  parms.push_back(temp);
-  temp = "-sPAPERSIZE=";
-  temp += prog_config.page_size;
-  parms.push_back(temp);
-  parms.push_back(basename);
-	
+
+  { // scope block for mutex lock
+    // lock the Prog_config object to stop it being modified in the intial (GUI) thread
+    // while we are accessing it here
+    Thread::Mutex::Lock lock(*prog_config.mutex_p);
+
+    std::string temp;
+    parms.push_back("gs");
+    parms.push_back("-q");
+    parms.push_back("-sDEVICE=tiffg3");
+    temp = "-r";
+    temp += prog_config.resolution;
+    parms.push_back(temp);
+    parms.push_back("-dNOPAUSE");
+    parms.push_back("-dSAFER");
+    temp = "-sOutputFile=";
+    temp += basename + ".%03d";
+    parms.push_back(temp);
+    temp = "-sPAPERSIZE=";
+    temp += prog_config.page_size;
+    parms.push_back(temp);
+    parms.push_back(basename);
+  }
+
   char** exec_parms = new char*[parms.size() + 1];
 
   std::vector<std::string>::const_iterator iter;
