@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -56,6 +56,10 @@ COPYING distributed with the source files.
 #include "utils/shared_handle.h"
 #include "utils/utf8_utils.h"
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
 #ifdef HAVE_STRINGSTREAM
 #include <sstream>
 #else
@@ -530,19 +534,23 @@ void FaxListDialog::print_fax_prompt(void) {
 
 std::pair<const char*, char* const*> FaxListDialog::get_print_from_stdin_parms(void) {
 
-  // lock the Prog_config object to stop it being modified or accessed in the initial (GUI)
-  // thread while we are accessing it here
-  Thread::Mutex::Lock lock(*prog_config.mutex_p);
   std::vector<std::string> print_parms;
   std::string print_cmd;
   std::string print_name;
   std::string::size_type end_pos;
-  try {
-    print_cmd = Utf8::filename_from_utf8(prog_config.print_cmd);
-  }
-  catch (Utf8::ConversionError&) {
-    write_error("UTF-8 conversion error in FaxListDialog::print_from_stdin()\n");
-    return std::pair<const char*, char* const*>(0,0);
+
+  { // scope block for mutex lock
+    // lock the Prog_config object to stop it being modified or accessed in the initial (GUI)
+    // thread while we are accessing it here
+    Thread::Mutex::Lock lock(*prog_config.mutex_p);
+
+    try {
+      print_cmd = Utf8::filename_from_utf8(prog_config.print_cmd);
+    }
+    catch (Utf8::ConversionError&) {
+      write_error("UTF-8 conversion error in FaxListDialog::print_from_stdin()\n");
+      return std::pair<const char*, char* const*>(0,0);
+    }
   }
   
   if ((end_pos = print_cmd.find_first_of(' ')) != std::string::npos) { // we have parms
@@ -589,148 +597,151 @@ std::pair<const char*, char* const*> FaxListDialog::get_print_from_stdin_parms(v
 std::pair<const char*, char* const*> FaxListDialog::get_fax_to_ps_parms
                                        (const std::string& basename, bool allow_shrink) {
 
-  // lock the Prog_config object to stop it being modified or accessed in the initial (GUI)
-  // thread while we are accessing it here
-  Thread::Mutex::Lock lock(*prog_config.mutex_p);
-
   // set up the parms for efix
   std::vector<std::string> efix_parms;
   std::string temp;
     
-  efix_parms.push_back("efix-0.9a");
-  // shut up efix (comment out next line and uncomment following one if errors to be reported)
-  efix_parms.push_back("-v");
-  //efix_parms.push_back("-ve");
-  efix_parms.push_back("-r300");
-  efix_parms.push_back("-ops");
-  temp = "-p";
-  temp += prog_config.page_dim;
-  efix_parms.push_back(temp);
+  { // scope block for mutex lock
+
+    // lock the Prog_config object to stop it being modified or accessed in the initial (GUI)
+    // thread while we are accessing it here
+    Thread::Mutex::Lock lock(*prog_config.mutex_p);
+
+    efix_parms.push_back("efix-0.9a");
+    // shut up efix (comment out next line and uncomment following one if errors to be reported)
+    efix_parms.push_back("-v");
+    //efix_parms.push_back("-ve");
+    efix_parms.push_back("-r300");
+    efix_parms.push_back("-ops");
+    temp = "-p";
+    temp += prog_config.page_dim;
+    efix_parms.push_back(temp);
 
 #ifdef HAVE_STRINGSTREAM
-  if (allow_shrink && prog_config.print_shrink.compare("100")) { // if print_shrink is not 100
-    temp = "-s0.";
-    temp += prog_config.print_shrink;
-    efix_parms.push_back(temp);
+    if (allow_shrink && prog_config.print_shrink.compare("100")) { // if print_shrink is not 100
+      temp = "-s0.";
+      temp += prog_config.print_shrink;
+      efix_parms.push_back(temp);
 
+      std::ostringstream strm;
+      if (!prog_config.page_size.compare("a4")) {
+
+	strm << "-d";
+	float val = 210 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << static_cast<int>(val + 0.5);
+	val = 297 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << ',' << static_cast<int>(val + 0.5) << "mm";
+      
+	efix_parms.push_back(strm.str());
+      }
+
+      else if (!prog_config.page_size.compare("letter")) {
+
+	strm << "-d";
+	float val = 216 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << static_cast<int>(val + 0.5);
+	val = 279 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << ',' << static_cast<int>(val + 0.5) << "mm";
+
+	efix_parms.push_back(strm.str());
+      }
+
+      else if (!prog_config.page_size.compare("legal")) {
+
+	strm << "-d";
+	float val = 216 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << static_cast<int>(val + 0.5);
+	val = 356 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << ',' << static_cast<int>(val + 0.5) << "mm";
+
+	efix_parms.push_back(strm.str());
+      }
+    }
+
+    int partnumber = 1;
     std::ostringstream strm;
-    if (!prog_config.page_size.compare("a4")) {
-
-      strm << "-d";
-      float val = 210 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << static_cast<int>(val + 0.5);
-      val = 297 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << ',' << static_cast<int>(val + 0.5) << "mm";
-      
-      efix_parms.push_back(strm.str());
-    }
-    
-    else if (!prog_config.page_size.compare("letter")) {
-
-      strm << "-d";
-      float val = 216 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << static_cast<int>(val + 0.5);
-      val = 279 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << ',' << static_cast<int>(val + 0.5) << "mm";
-      
-      efix_parms.push_back(strm.str());
-    }
-
-    else if (!prog_config.page_size.compare("legal")) {
-
-      strm << "-d";
-      float val = 216 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << static_cast<int>(val + 0.5);
-      val = 356 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << ',' << static_cast<int>(val + 0.5) << "mm";
-      
-      efix_parms.push_back(strm.str());
-    }
-  }
-
-  int partnumber = 1;
-  std::ostringstream strm;
-  strm << basename.c_str() << std::setfill('0')
-       << std::setw(3) << partnumber;
-  int result = access(strm.str().c_str(), R_OK);
-    
-  while (!result) {
-    efix_parms.push_back(strm.str());
-	
-    partnumber++;
-    strm.str("");
     strm << basename.c_str() << std::setfill('0')
 	 << std::setw(3) << partnumber;
-    result = access(strm.str().c_str(), R_OK);
-  }
+    int result = access(strm.str().c_str(), R_OK);
+
+    while (!result) {
+      efix_parms.push_back(strm.str());
+	
+      partnumber++;
+      strm.str("");
+      strm << basename.c_str() << std::setfill('0')
+	   << std::setw(3) << partnumber;
+      result = access(strm.str().c_str(), R_OK);
+    }
 
 #else
-  if (allow_shrink && prog_config.print_shrink.compare("100")) { // if print_shrink is not 100
-    temp = "-s0.";
-    temp += prog_config.print_shrink;
-    efix_parms.push_back(temp);
+    if (allow_shrink && prog_config.print_shrink.compare("100")) { // if print_shrink is not 100
+      temp = "-s0.";
+      temp += prog_config.print_shrink;
+      efix_parms.push_back(temp);
 
-    std::ostrstream strm;
-    if (!prog_config.page_size.compare("a4")) {
+      std::ostrstream strm;
+      if (!prog_config.page_size.compare("a4")) {
 
-      strm << "-d";
-      float val = 210 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << static_cast<int>(val + 0.5);
-      val = 297 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << ',' << static_cast<int>(val + 0.5) << "mm" << std::ends;
-      
-      const char* dim = strm.str();
-      efix_parms.push_back(dim);
-      delete[] dim;
-    }
+	strm << "-d";
+	float val = 210 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << static_cast<int>(val + 0.5);
+	val = 297 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << ',' << static_cast<int>(val + 0.5) << "mm" << std::ends;
+
+	const char* dim = strm.str();
+	efix_parms.push_back(dim);
+	delete[] dim;
+      }
     
-    else if (!prog_config.page_size.compare("letter")) {
+      else if (!prog_config.page_size.compare("letter")) {
+
+	strm << "-d";
+	float val = 216 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << static_cast<int>(val + 0.5);
+	val = 279 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << ',' << static_cast<int>(val + 0.5) << "mm" << std::ends;
+
+	const char* dim = strm.str();
+	efix_parms.push_back(dim);
+	delete[] dim;
+      }
+
+      else if (!prog_config.page_size.compare("legal")) {
+
+	strm << "-d";
+	float val = 216 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << static_cast<int>(val + 0.5);
+	val = 356 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
+	strm << ',' << static_cast<int>(val + 0.5) << "mm" << std::ends;
 
-      strm << "-d";
-      float val = 216 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << static_cast<int>(val + 0.5);
-      val = 279 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << ',' << static_cast<int>(val + 0.5) << "mm" << std::ends;
-      
       const char* dim = strm.str();
       efix_parms.push_back(dim);
       delete[] dim;
+      }
     }
 
-    else if (!prog_config.page_size.compare("legal")) {
-
-      strm << "-d";
-      float val = 216 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << static_cast<int>(val + 0.5);
-      val = 356 * (100 - std::atoi(prog_config.print_shrink.c_str()))/200.0;
-      strm << ',' << static_cast<int>(val + 0.5) << "mm" << std::ends;
-      
-      const char* dim = strm.str();
-      efix_parms.push_back(dim);
-      delete[] dim;
-    }
-  }
-
-  int partnumber = 1;
-  std::ostrstream strm;
-  strm << basename.c_str() << std::setfill('0')
-       << std::setw(3) << partnumber << std::ends;
-  const char* file_name = strm.str();
-  int result = access(file_name, R_OK);
-    
-  while (!result) {
-    efix_parms.push_back(file_name);
-    delete[] file_name;
-	
-    partnumber++;
+    int partnumber = 1;
     std::ostrstream strm;
     strm << basename.c_str() << std::setfill('0')
 	 << std::setw(3) << partnumber << std::ends;
-    file_name = strm.str();
-    result = access(file_name, R_OK);
-  }
-  delete[] file_name;
+    const char* file_name = strm.str();
+    int result = access(file_name, R_OK);
+
+    while (!result) {
+      efix_parms.push_back(file_name);
+      delete[] file_name;
+
+      partnumber++;
+      std::ostrstream strm;
+      strm << basename.c_str() << std::setfill('0')
+	   << std::setw(3) << partnumber << std::ends;
+      file_name = strm.str();
+      result = access(file_name, R_OK);
+    }
+    delete[] file_name;
 #endif
+  } // end of mutex lock scope block
 
   char** exec_parms = new char*[efix_parms.size() + 1];
 
@@ -774,20 +785,23 @@ void FaxListDialog::write_from_stdin(int dest_fd) {
 
 std::pair<const char*, char* const*> FaxListDialog::get_ps_viewer_parms(const char* filename) {
 
-  // lock the Prog_config object to stop it being modified or accessed in the initial (GUI)
-  // thread while we are accessing it here
-  Thread::Mutex::Lock lock(*prog_config.mutex_p);
-
   std::vector<std::string> view_parms;
   std::string view_cmd;
   std::string view_name;
   std::string::size_type end_pos;
-  try {
-    view_cmd = Utf8::filename_from_utf8(prog_config.ps_view_cmd);
-  }
-  catch (Utf8::ConversionError&) {
-    write_error("UTF-8 conversion error in FaxListDialog::ps_viewer()\n");
-    return std::pair<const char*, char* const*>(0,0);
+
+  { // scope block for mutex lock
+
+    // lock the Prog_config object to stop it being modified or accessed in the initial (GUI)
+    // thread while we are accessing it here
+    Thread::Mutex::Lock lock(*prog_config.mutex_p);
+    try {
+      view_cmd = Utf8::filename_from_utf8(prog_config.ps_view_cmd);
+    }
+    catch (Utf8::ConversionError&) {
+      write_error("UTF-8 conversion error in FaxListDialog::ps_viewer()\n");
+      return std::pair<const char*, char* const*>(0,0);
+    }
   }
 
   if ((end_pos = view_cmd.find_first_of(' ')) != std::string::npos) { // we have parms
