@@ -19,9 +19,9 @@ COPYING distributed with the source files.
 
 #include <sigc++/sigc++.h>
 
-#include "window.h"
 #include "fax_list_manager.h"
-#include "sem_sync.h"
+#include "utils/window.h"
+#include "utils/sem_sync.h"
 
 namespace { // we put the function in anonymous namespace in fax_list.cpp
             // so it is not exported at link time
@@ -49,7 +49,9 @@ class FaxListDialog: public sigc::trackable, public WinBase {
   GtkWidget* empty_trash_button_p;
   GtkWidget* add_folder_button_p;
   GtkWidget* delete_folder_button_p;
-  GtkWidget* refresh_button_p;
+  GtkWidget* reset_button_p;
+
+  GtkWidget* new_fax_label_p;
 
   void set_buttons_slot(void);
   void describe_fax_prompt(void);
@@ -70,10 +72,20 @@ class FaxListDialog: public sigc::trackable, public WinBase {
   void delete_parms(std::pair<const char*, char* const*>);
 public:
   friend void FaxListDialogCB::fax_list_button_clicked(GtkWidget*, void*);
+
+  sigc::signal0<int> get_new_fax_count_sig;
+  sigc::signal0<void> reset_sig;
+
+  // display_new_fax_count() calls get_new_fax_count_sig, so until it has been
+  // connected to a function which returns this, it will show 0 as the count
+  void display_new_fax_count(void);
   static int get_is_fax_received_list(void) {return is_fax_received_list;}
   static int get_is_fax_sent_list(void) {return is_fax_sent_list;}
+  void insert_new_fax_slot(const std::pair<std::string, std::string>& fax_info) {
+    fax_list_manager.insert_new_fax_in_base(fax_info.first, fax_info.second);
+    display_new_fax_count();
+  }
 
-  void refresh(void);
   FaxListDialog(FaxListEnum::Mode, const int standard_size_);
   ~FaxListDialog(void);
 };
