@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -29,6 +29,10 @@ COPYING distributed with the source files.
 #include <gdk/gdkpixmap.h>
 #include <glib/gmain.h>
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
 // a guess for the future!
 #if GTK_MAJOR_VERSION > 2
 #define HAVE_EXPAND_TO_PATH 1
