@@ -29,10 +29,10 @@ COPYING distributed with the source files.
 
 #include <sigc++/sigc++.h>
 
-#include "shared_handle.h"
-#include "gobj_handle.h"
-#include "tree_row_reference_handle.h"
-#include "selected_rows_handle.h"
+#include "utils/shared_handle.h"
+#include "utils/gobj_handle.h"
+#include "utils/tree_row_reference_handle.h"
+#include "utils/selected_rows_handle.h"
 
 
 typedef std::map<TreeRowRefSharedHandle, GobjHandle<GtkTreeModel> > FolderRowToFaxModelMap;
@@ -78,6 +78,9 @@ namespace FaxListManagerCB {
 
 class FaxListManager: public sigc::trackable {
 
+  static bool fax_received_list_main_iteration;
+  static bool fax_sent_list_main_iteration;
+
   FaxListEnum::Mode mode;
   guint timer_tag;
 
@@ -95,6 +98,7 @@ class FaxListManager: public sigc::trackable {
   GtkTreeView* folder_tree_view_p;
   GtkTreeView* fax_tree_view_p;
   GobjHandle<GtkTreeModel> folder_tree_store_h;
+  GobjHandle<GtkTreeModel> fax_base_model_h;
   FolderRowToFaxModelMap folder_row_to_fax_model_map;
 
   GobjHandle<GdkPixbuf> folder_icon_h;
@@ -116,6 +120,7 @@ class FaxListManager: public sigc::trackable {
   void display_faxes(void);
   void write_path(void);
   void write_paths_for_level(const GtkTreeIter*, std::ofstream&);
+  std::string convert_faxname_to_date(const std::string&);
 
 public:
   friend void FaxListManagerCB::folder_tree_view_drag_begin(GtkWidget*, GdkDragContext*, void*);
@@ -146,9 +151,9 @@ public:
     return folder_name_validator.validate(folder_name);
   }
   void make_folder(const std::string&, bool test_valid = true);
-  void refresh(void);
   void describe_fax(const std::string&);
   void empty_trash_folder(void);
+  void insert_new_fax_in_base(const std::string&, const std::string&);
 
   RowPathList::size_type is_fax_selected(void);
   bool is_folder_selected(void);
@@ -159,6 +164,9 @@ public:
   bool are_selected_faxes_in_trash_folder(void);
   void move_selected_faxes_to_trash_folder(void);
 
+  static bool is_fax_received_list_main_iteration(void) {return fax_received_list_main_iteration;}
+  static bool is_fax_sent_list_main_iteration(void) {return fax_sent_list_main_iteration;}
+
   GcharSharedHandle get_fax_number(void);
   GcharSharedHandle get_fax_description(void);
   GcharSharedHandle get_folder_name(void);
