@@ -38,11 +38,11 @@ COPYING distributed with the source files.
 
 #include "file_list.h"
 #include "dialogs.h"
-#include "mutex.h"
 #include "file_list_icons.h"
-#include "tree_path_handle.h"
-#include "shared_handle.h"
-#include "utf8_utils.h"
+#include "utils/mutex.h"
+#include "utils/tree_path_handle.h"
+#include "utils/shared_handle.h"
+#include "utils/utf8_utils.h"
 
 #ifdef ENABLE_NLS
 #include <libintl.h>
@@ -159,7 +159,7 @@ FileListDialog::FileListDialog(const int standard_size_, GtkWindow* parent_p):
   GtkTreeViewColumn* column_p =
     gtk_tree_view_column_new_with_attributes(gettext("Files to fax"), renderer_p,
 					     "text", ModelColumns::file_name,
-					     0);
+					     static_cast<void*>(0));
   gtk_tree_view_append_column(tree_view_p, column_p);
 
   GtkTreeSelection* selection_p = gtk_tree_view_get_selection(tree_view_p);
@@ -440,7 +440,7 @@ void FileListDialog::add_file(void) {
   }
 }
 
-std::pair<const char*, char* const*> FileListDialog::get_view_file_parms(const string& file_name) {
+std::pair<const char*, char* const*> FileListDialog::get_view_file_parms(const std::string& file_name) {
 
   std::vector<std::string> view_parms;
   std::string view_cmd;
