@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -26,17 +26,28 @@ COPYING distributed with the source files.
 #include <cstring>
 #include <ctime>
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
+#ifdef HAVE_ISTREAM
+#include <istream>
+#endif
+
 #include <gtk/gtkmain.h>
 #include <gtk/gtkversion.h>
 
 #include <gdk/gdkpixbuf.h>
-#include <gdk/gdkx.h>  // for GDK_DISPLAY()
-#include <gdk/gdk.h>   // for gdk_notify_startup_complete()
-#include <X11/Xlib.h>
+#include <gdk/gdk.h>   // for gdk_notify_startup_complete() and gdk_beep()
 
 #include <glib/gutils.h>
 #include <glib/gthread.h>
 
+#ifdef HAVE_X11_XLIB_H
+#include <X11/Xlib.h>
+#include <gdk/gdkx.h>  // for GDK_DISPLAY()
+#endif
+
 // a guess for the future!
 #if GTK_MAJOR_VERSION > 2
 #define EFAX_GTK_USE_ICON_THEME 1
@@ -175,6 +186,15 @@ int main(int argc, char* argv[]) {
     gtk_init(&argc, &argv);
     g_atexit(atexit_cleanup);
 
+    // initialise Notifier objects
+    try {
+      Notifier::init();
+    }
+    catch (PipeError& error) {
+      std::cerr << error.error_message;
+      std::exit(PIPE_ERROR);
+    }
+
     get_fonts();
 
     get_window_icon();
@@ -236,10 +256,6 @@ int main(int argc, char* argv[]) {
 	std::cerr << error.error_message;
 	std::exit(PIPE_ERROR);
       }
-      catch (NotifierError& error) {
-	std::cerr << error.error_message;
-	std::exit(NOTIFIER_ERROR);
-      }
     }
   }
 #ifdef HAVE_NOTIFY_STARTUP
@@ -617,7 +633,10 @@ std::string configure_prog(bool reread) {
 	}
 	
 	prog_config.lock_file += "/LCK..";
-	prog_config.lock_file += device;
+	temp = device;
+	// replace any '/' characters with '_' character
+	std::replace(temp.begin(), temp.end(), '/', '_');
+	prog_config.lock_file += temp;
 	
 	temp = "-d/dev/";
 	temp += locale_device;
@@ -809,6 +828,7 @@ std::string configure_prog(bool reread) {
 
 void get_fonts(void) {
 
+#ifdef HAVE_X11_XLIB_H
   // this will get a suitable fixed font for GplDialog and HelpDialog to use with Pango
   const int MAX_FONTS = 10000;
   int num_fonts;
@@ -831,8 +851,13 @@ void get_fonts(void) {
 
     // unsuccessful -- go for the generic "fixed" font
     if (prog_config.fixed_font.empty()) prog_config.fixed_font = "fixed";
+
+    XFreeFontNames(fonts);
   }
-  XFreeFontNames(fonts);
+  else prog_config.fixed_font = "fixed";
+#else
+  prog_config.fixed_font = "fixed";
+#endif
 }
 
 bool get_prog_parm(const char* name, std::string& line, std::string& result,
@@ -845,7 +870,7 @@ bool get_prog_parm(const char* name, std::string& line, std::string& result,
 // converted (when placed into `result') to UTF-8, using the function
 // assigned to function pointer convert_func (you would normally use
 // Utf8::locale_to_utf8() or Utf8::filename_to_utf8(), and there is a
-// default inline function using Utf8::locale_to_utf8()
+// default inline function using Utf8::locale_to_utf8())
 
   const std::string::size_type length = std::strlen(name);
   // we have to use std::string::substr() because libstdc++-2
@@ -872,7 +897,11 @@ bool get_prog_parm(const char* name, std::string& line, std::string& result,
 }
 
 void beep(void) {
+#ifdef HAVE_X11_XLIB_H
   XBell(GDK_DISPLAY(), 0);
+#else
+  gdk_beep();
+#endif
 }
 
 void get_window_icon(void) {
