@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -18,6 +18,14 @@ COPYING distributed with the source files.
 #include <cstdlib>
 #include <cstring>
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
+#ifdef HAVE_ISTREAM
+#include <istream>
+#endif
+
 #include <gtk/gtkcontainer.h>
 #include <gtk/gtkbox.h>
 #include <gtk/gtkhbox.h>
@@ -1040,17 +1048,45 @@ void MainWindow::socket_list_impl(void) {
 
 void MainWindow::socket_filelist_changed_notify_slot(void) {
 
-  // this slot is connected to the socket_server object, and is called
-  // by a Notifier object (filelist_changed_notify) whenever the
-  // socket server gets a new fax to send
+  /*
+   This slot calls SocketListDialog::set_socket_list_rows() via the
+   MainWindow::update_socket_list signal so updating the socket list
+   dialog if that dialog happens to be displayed, and also calls
+   gtk_widget_queue_draw() on the drawing_area_p object maintained by
+   the MainWindow object to force it to redraw
 
-  // update_socket_list is a signal, connected to SocketListDialog::set_socket_list_rows
-  // and it will enter the new fax file received from the socket server into the list of
-  // queued faxes to be sent maintained by the SocketListDialog object
+   This slot is connected to the SocketServer::filelist_changed_notify
+   Notifier object
 
+   The SocketServer::filelist_changed_notify signal is emitted by
+   SocketServer:read_socket() when a new fax file to be sent is
+   received via the socket and also by SocketServer::remove_file().
+
+   SocketServer::remove_file() is called by
+   MainWindow::remove_from_socket_server_filelist()
+
+   MainWindow::remove_from_socket_server_filelist() is connected to
+   the EfaxController::remove_from_socket_server_filelist signal and
+   to the SocketListDialog::remove_from_socket_server_filelist signal
+
+   The EfaxController::remove_from_socket_server_filelist signal is
+   emitted by EfaxController::timer_event() when a fax derived from
+   the socket list is successfully sent
+
+   The SocketListDialog::remove_from_socket_server_filelist signal is
+   emitted by SocketListDialog::remove_file()
+
+   SocketListDialog::remove_file() is connected to the
+   PromptDialog::accepted signal (emitted when a user elects to delete
+   a queued fax from the list of files received for faxing from the
+   socket)
+  */
+
+  // If a SocketListDialog object exists, cause it to update its display
   update_socket_list(socket_server.get_filenames());
 
-  draw_fax_from_socket_notifier();
+  // trigger an expose event for the drawing area
+  gtk_widget_queue_draw(drawing_area_p);
 }
 
 void MainWindow::socket_filelist_closed_slot(void) {
@@ -1335,7 +1371,7 @@ void MainWindow::about_impl(bool efax_gtk) {
 
   if (efax_gtk) {
     std::string message("efax-gtk-" VERSION "\n");
-    message += gettext("Copyright (C) 2001 - 2005 Chris Vine\n\n"
+    message += gettext("Copyright (C) 2001 - 2006 Chris Vine\n\n"
 		       "This program is released under the "
 		       "GNU General Public License, version 2");
     dialog_p = new InfoDialog(message.c_str(), gettext("About efax-gtk"),
@@ -1365,7 +1401,11 @@ void MainWindow::translations_impl(void) {
   message += gettext("Greek - Hellenic Linux Users Group\n");
   message += gettext("Albanian - Besnik Bleta\n");
   message += gettext("Hungarian - Gergely Szakats\n");
-  message += gettext("Simplified Chinese - Kite Lau");
+  message += gettext("Simplified Chinese - Kite Lau\n");
+  message += gettext("German - Steffen Wagner\n");
+  message += gettext("Swedish - Daniel Nylander\n");
+  message += gettext("Catalan - Jordi Sayol Salomo\n");
+
   new InfoDialog(message.c_str(), gettext("efax-gtk: Translations"),
 		 GTK_MESSAGE_INFO, get_win());
 
@@ -1507,31 +1547,41 @@ bool MainWindow::draw_fax_from_socket_notifier(void) {
 
    - it is called in MainWindowCB::mainwin_drawing_area_expose_event(),
      handling the signal_expose_event signal of the
-     MainWindow::drawing_area_p object and is also called in
-     MainWindow::socket_filelist_changed_notify_slot()
+     MainWindow::drawing_area_p object
+
+   - MainWindowCB::mainwin_drawing_area_expose_event() will in turn be
+     called either because of a normal expose event on the desktop, or
+     because MainWindow::socket_filelist_changed_notify_slot() has
+     been invoked which calls gtk_widget_queue_draw() on the
+     drawing_area_p object to force it to redraw
+     (MainWindow::socket_filelist_changed_notify_slot() also calls
+     SocketListDialog::set_socket_list_rows() via the
+     MainWindow::update_socket_list signal so updating the socket list
+     dialog if that dialog happens to be displayed)
 
    - MainWindow::socket_filelist_changed_notify_slot() is connected to
-     the SocketServer::filelist_changed_notify signal - the
-     SocketServer::filelist_changed_notify signal is emitted by
-     SocketServer:read_socket() when a new fax file to be sent
-     is received via the socket and also by
-     SocketServer::remove_file()
+     the SocketServer::filelist_changed_notify Notifier object
+
+   - the SocketServer::filelist_changed_notify signal is emitted by
+     SocketServer:read_socket() when a new fax file to be sent is
+     received via the socket and also by SocketServer::remove_file().
 
    - SocketServer::remove_file() is called by
      MainWindow::remove_from_socket_server_filelist()
 
    - MainWindow::remove_from_socket_server_filelist() is connected to
      the EfaxController::remove_from_socket_server_filelist signal and
-     to SocketList::remove_from_socket_server_filelist()
+     to the SocketListDialog::remove_from_socket_server_filelist
+     signal
 
    - the EfaxController::remove_from_socket_server_filelist signal is
      emitted by EfaxController::timer_event() when a fax derived from
      the socket list is successfully sent
 
-   - the SocketServer::remove_from_socket_server_filelist signal is
-     emitted by SocketServer::remove_file()
+   - the SocketListDialog::remove_from_socket_server_filelist signal is
+     emitted by SocketListDialog::remove_file()
 
-   - SocketServer::remove_file() is connected to the
+   - SocketListDialog::remove_file() is connected to the
      PromptDialog::accepted signal (emitted when a user elects to
      delete a queued fax from the list of files received for faxing
      from the socket)
@@ -2068,9 +2118,11 @@ ssize_t write_error(const char* message) {
   // this writes to a pipe (which will provide asynchronous to
   // synchronous conversion) so it can be used by different threads
   // without upsetting GTK+. It also only uses async-signal-safe
-  // system functions and is thread safe with only a mutex in this
-  // function because (a) although PipeFifo::read() and
-  // PipeFifo::write() check the value of PipeFifo::read_fd and
+  // system functions if connect_to_stderr() has been called (which
+  // is only in a child process), and in the main process (where
+  // connect_to_stderr() is not called) is thread safe with only a
+  // mutex in this function because (a) although PipeFifo::read()
+  // and PipeFifo::write() check the value of PipeFifo::read_fd and
   // PipeFifo::write_fd respectively, and PipeFifo::open(),
   // PipeFifo::make_writeonly(), PipeFifo::make_readonly(),
   // PipeFifo::close(), PipeFifo::connect_to_stdin(),
@@ -2081,7 +2133,7 @@ ssize_t write_error(const char* message) {
   // (b) PipeFifo::connect_to_stderr() is only ever called after
   // fork()ing into a new single-threaded process
 
-  // The pipe which is non-blocking - it will be emptied fairly promptly
+  // The pipe is non-blocking - it will be emptied fairly promptly
   // but messages should be less than PIPE_BUF in length or any excess
   // will be lost unless the caller checks the return value and acts
   // accordingly
@@ -2106,12 +2158,15 @@ ssize_t write_error(const char* message) {
   }
 
   else {
-    // no mutex is required in this case: MainWindow::connect_to_stderr()
-    // is only called after fork()ing and it is for the new process to
-    // synchronise its writes to standard error (in efax-gtk child
-    // processes are all single-threaded anyway) and as between different
-    // processes, POSIX guarantees that writes not larger than PIPE_BUF
-    // in size will not be interleaved
+    // no mutex is required in this case: connect_to_stderr() is only
+    // called after fork()ing and it is for the new process to synchronise
+    // its writes to standard error (in efax-gtk child processes are all
+    // single-threaded anyway) and as between different processes, POSIX
+    // guarantees that writes not larger than PIPE_BUF in size will not be
+    // interleaved.  Since no mutex is used in this case, this function is
+    // async-signal-safe for child processes.  It can therefore be used
+    // after fork()ing before exec()ing even though this is a multi-threaded
+    // program
     do {
       result = ::write(2, message + written, to_write_count);
       if (result > 0) {
