@@ -40,17 +40,18 @@ COPYING distributed with the source files.
 #include "efax_controller.h"
 #include "fax_list_manager.h"
 #include "fax_list.h"
-#include "pipes.h"
 #include "socket_server.h"
 #include "socket_list.h"
 #include "tray_icon.h"
-#include "shared_ptr.h"
-#include "mutex.h"
 #include "helpfile.h"
-#include "widget.h"
-#include "gobj_handle.h"
-#include "notifier.h"
-#include "io_watch.h"
+#include "utils/pipes.h"
+#include "utils/shared_ptr.h"
+#include "utils/mutex.h"
+#include "utils/widget.h"
+#include "utils/gobj_handle.h"
+#include "utils/notifier.h"
+#include "utils/io_watch.h"
+#include "utils/utf8_utils.h"
 
 #define MAINWIN_SAVE_FILE ".efax-gtk_mainwin_save"
 
@@ -89,7 +90,7 @@ class StatusLine: public sigc::trackable, public MainWidgetBase {
   const int standard_size;
   GtkWidget* status_label_p;
 public:
-  void set_status_line(GtkStyle*, int);
+  void set_status_line(int);
   void write_status_slot(const char* text);
   StatusLine(const int);
 };
@@ -171,6 +172,8 @@ class MainWindow: public sigc::trackable, public WinBase {
 
   TrayItem tray_item;
 
+  Utf8::Reassembler error_pipe_reassembler;
+
   // these are called by handlers of GTK+ signals
   void close_impl(void);
   void get_file_impl(void);
@@ -192,7 +195,7 @@ class MainWindow: public sigc::trackable, public WinBase {
   // called by the handlers of GTK+ signals
   void sendfax_slot(void);
   void set_files_slot(const std::string&);
-  void fax_received_notify_slot(void);
+  void fax_received_notify_slot(const std::pair<std::string, std::string>&);
   void enter_socket_file_slot(const std::pair<std::string, std::string>&);
   void settings_changed_slot(const std::string&);
   void socket_filelist_changed_notify_slot(void);
