@@ -44,7 +44,6 @@ typedef unsigned int socklen_t;
 #define ARG_ERROR 16
 #define EXEC_ERROR 17
 #define FORK_ERROR 18
-#define NOTIFIER_ERROR 19
 
 #define RC_FILE "efax-gtkrc"
 
@@ -174,6 +173,12 @@ using namespace std;    // until I get a Std C++ compliant compiler to test with
    SocketListDialog::view_file() and
    SocketListDialog::get_view_file_parms() (in socket_list.cpp).)
 
+   The global lock Prog_config::mutex_p is provided for the purpose.
+   Global locks are quite dangerous - they can easily lead to
+   deadlocks from out-of-order locking of other mutexes.  Accordingly,
+   only lock Prog_config::mutex_p if no other mutex locks are being
+   held.
+
 5. See also the comments about thread sefety in the function
    write_error() in mainwindow.cpp.
 
