@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -27,6 +27,7 @@ COPYING distributed with the source files.
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtkradiobutton.h>
 #include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkspinbutton.h>
 #include <gtk/gtkbox.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
@@ -267,11 +268,14 @@ ModemPage::ModemPage(const int standard_size):
   device_entry_p = gtk_entry_new();
   lock_entry_p = gtk_entry_new();
   capabilities_entry_p = gtk_entry_new();
-  rings_entry_p = gtk_entry_new();
   gtk_widget_set_size_request(device_entry_p, standard_size * 7, standard_size);
   gtk_widget_set_size_request(lock_entry_p, standard_size * 7, standard_size);
   gtk_widget_set_size_request(capabilities_entry_p, standard_size * 7, standard_size);
-  gtk_widget_set_size_request(rings_entry_p, standard_size * 7, standard_size);
+
+  rings_spin_button_p = gtk_spin_button_new_with_range(1, 9, 1);
+  gtk_widget_set_size_request(rings_spin_button_p, -1, standard_size);
+  GtkWidget* rings_spin_button_alignment_p = gtk_alignment_new(0, 0.5, 0, 1);
+  gtk_container_add(GTK_CONTAINER(rings_spin_button_alignment_p), rings_spin_button_p);
 
   device_help_button_p = gtk_button_new();
   lock_help_button_p = gtk_button_new();
@@ -339,7 +343,7 @@ ModemPage::ModemPage(const int standard_size):
 		   0, 1, 3, 4,
 		   GTK_FILL, GTK_SHRINK,
 		   standard_size/5, standard_size/5);
-  gtk_table_attach(table_p, rings_entry_p,
+  gtk_table_attach(table_p, rings_spin_button_alignment_p,
 		   1, 2, 3, 4,
 		   GtkAttachOptions(GTK_FILL | GTK_EXPAND), GTK_SHRINK,
 		   standard_size/5, standard_size/5);
@@ -417,7 +421,7 @@ std::string ModemPage::get_capabilities(void) const {
 }
 
 std::string ModemPage::get_rings(void) const {
-  return gtk_entry_get_text(GTK_ENTRY(rings_entry_p));
+  return gtk_entry_get_text(GTK_ENTRY(rings_spin_button_p));
 }
 
 std::string ModemPage::get_class(void) const {
@@ -449,7 +453,8 @@ void ModemPage::set_capabilities(const std::string& capabilities) {
 }
 
 void ModemPage::set_rings(const std::string& rings) {
-  gtk_entry_set_text(GTK_ENTRY(rings_entry_p), rings.c_str());
+  gtk_entry_set_text(GTK_ENTRY(rings_spin_button_p), rings.c_str());
+  gtk_spin_button_update(GTK_SPIN_BUTTON(rings_spin_button_p));
 }
 
 void ModemPage::set_class(const std::string& class_string) {
@@ -481,7 +486,8 @@ void ModemPage::clear(void) {
   gtk_entry_set_text(GTK_ENTRY(device_entry_p), "");
   gtk_entry_set_text(GTK_ENTRY(lock_entry_p), "");
   gtk_entry_set_text(GTK_ENTRY(capabilities_entry_p), "");
-  gtk_entry_set_text(GTK_ENTRY(rings_entry_p), "");
+  gtk_entry_set_text(GTK_ENTRY(rings_spin_button_p), "1");
+  gtk_spin_button_update(GTK_SPIN_BUTTON(rings_spin_button_p));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(auto_button_p), true);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tone_button_p), true);
 }
@@ -679,11 +685,14 @@ PrintPage::PrintPage(const int standard_size):
   gtk_misc_set_alignment(GTK_MISC(popup_label_p), 1, 0.5);
   
   command_entry_p = gtk_entry_new();
-  shrink_entry_p = gtk_entry_new();
   gtk_widget_set_size_request(command_entry_p, standard_size * 7, standard_size);
-  gtk_widget_set_size_request(shrink_entry_p, standard_size * 7, standard_size);
 
-  GtkWidget* popup_button_alignment_p = gtk_alignment_new(1, 0.5, 0, 1);
+  shrink_spin_button_p = gtk_spin_button_new_with_range(50, 100, 1);
+  gtk_widget_set_size_request(shrink_spin_button_p, -1, standard_size);
+  GtkWidget* shrink_spin_button_alignment_p = gtk_alignment_new(0, 0.5, 0, 1);
+  gtk_container_add(GTK_CONTAINER(shrink_spin_button_alignment_p), shrink_spin_button_p);
+
+  GtkWidget* popup_button_alignment_p = gtk_alignment_new(0, 0.5, 0, 1);
   popup_check_button_p = gtk_check_button_new();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(popup_check_button_p), true); // this is the default
   gtk_container_add(GTK_CONTAINER(popup_button_alignment_p),
@@ -720,7 +729,7 @@ PrintPage::PrintPage(const int standard_size):
 		   0, 1, 1, 2,
 		   GTK_FILL, GTK_SHRINK,
 		   standard_size/3, standard_size/2);
-  gtk_table_attach(table_p, shrink_entry_p,
+  gtk_table_attach(table_p, shrink_spin_button_alignment_p,
 		   1, 2, 1, 2,
 		   GtkAttachOptions(GTK_FILL | GTK_EXPAND), GTK_SHRINK,
 		   standard_size/3, standard_size/2);
@@ -765,7 +774,7 @@ std::string PrintPage::get_command(void) const {
 }
 
 std::string PrintPage::get_shrink(void) const {
-  return gtk_entry_get_text(GTK_ENTRY(shrink_entry_p));
+  return gtk_entry_get_text(GTK_ENTRY(shrink_spin_button_p));
 }
 
 std::string PrintPage::get_popup(void) const {
@@ -781,7 +790,8 @@ void PrintPage::set_command(const std::string& command) {
 }
 
 void PrintPage::set_shrink(const std::string& shrink) {
-  gtk_entry_set_text(GTK_ENTRY(shrink_entry_p), shrink.c_str());
+  gtk_entry_set_text(GTK_ENTRY(shrink_spin_button_p), shrink.c_str());
+  gtk_spin_button_update(GTK_SPIN_BUTTON(shrink_spin_button_p));
 }
 
 void PrintPage::set_popup(const std::string& popup_string) {
@@ -795,7 +805,8 @@ void PrintPage::set_popup(const std::string& popup_string) {
 
 void PrintPage::clear(void) {
   gtk_entry_set_text(GTK_ENTRY(command_entry_p), "");
-  gtk_entry_set_text(GTK_ENTRY(shrink_entry_p), "");
+  gtk_entry_set_text(GTK_ENTRY(shrink_spin_button_p), "1");
+  gtk_spin_button_update(GTK_SPIN_BUTTON(shrink_spin_button_p));
 }
 
 namespace { // callback for internal use only
@@ -925,8 +936,10 @@ SockPage::SockPage(const int standard_size):
   gtk_container_add(GTK_CONTAINER(popup_button_alignment_p),
 		    popup_button_p);
 
-  port_entry_p = gtk_entry_new();
-  gtk_widget_set_size_request(port_entry_p, standard_size * 7, standard_size);
+  port_spin_button_p = gtk_spin_button_new_with_range(1024, 65535, 1);
+  gtk_widget_set_size_request(port_spin_button_p, -1, standard_size);
+  GtkWidget* port_spin_button_alignment_p = gtk_alignment_new(0, 0.5, 0, 1);
+  gtk_container_add(GTK_CONTAINER(port_spin_button_alignment_p), port_spin_button_p);
 
   other_addresses_entry_p = gtk_entry_new();
   gtk_editable_set_editable(GTK_EDITABLE(other_addresses_entry_p), false);
@@ -1005,7 +1018,7 @@ SockPage::SockPage(const int standard_size):
 		   0, 1, 2, 3,
 		   GTK_FILL, GTK_SHRINK,
 		   standard_size/4, standard_size/3);
-  gtk_table_attach(table_p, port_entry_p,
+  gtk_table_attach(table_p, port_spin_button_alignment_p,
 		   1, 2, 2, 3,
 		   GtkAttachOptions(GTK_FILL | GTK_EXPAND), GTK_SHRINK,
 		   standard_size/4, standard_size/3);
@@ -1068,7 +1081,7 @@ std::string SockPage::get_popup(void) const {
 }
 
 std::string SockPage::get_port(void) const {
-  return gtk_entry_get_text(GTK_ENTRY(port_entry_p));
+  return gtk_entry_get_text(GTK_ENTRY(port_spin_button_p));
 }
 
 std::string SockPage::get_if_other_address(void) const {
@@ -1102,7 +1115,8 @@ void SockPage::set_popup(const std::string& popup_string) {
 }
 
 void SockPage::set_port(const std::string& port_string) {
-  gtk_entry_set_text(GTK_ENTRY(port_entry_p), port_string.c_str());
+  gtk_entry_set_text(GTK_ENTRY(port_spin_button_p), port_string.c_str());
+  gtk_spin_button_update(GTK_SPIN_BUTTON(port_spin_button_p));
 }
 
 void SockPage::set_if_other_address(const std::string& if_other_address_string) {
@@ -1123,7 +1137,8 @@ void SockPage::clear(void) {
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(popup_button_p), false);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(other_address_button_p), false);
 
-  gtk_entry_set_text(GTK_ENTRY(port_entry_p), "");
+  gtk_entry_set_text(GTK_ENTRY(port_spin_button_p), "9900");
+  gtk_spin_button_update(GTK_SPIN_BUTTON(port_spin_button_p));
   gtk_entry_set_text(GTK_ENTRY(other_addresses_entry_p), "");
 }
 
@@ -1439,7 +1454,7 @@ PagePage::PagePage(const int standard_size):
 
   GtkWidget* page_box_alignment_p = gtk_alignment_new(0, 0.5, 0, 1);
   GtkWidget* res_box_alignment_p = gtk_alignment_new(0, 0.5, 0, 1);
-  GtkWidget* header_button_alignment_p = gtk_alignment_new(1, 0.5, 0, 1);
+  GtkWidget* header_button_alignment_p = gtk_alignment_new(0, 0.5, 0, 1);
 
   GtkBox* page_box_p = GTK_BOX(gtk_hbox_new(false, 2));
   GtkBox* res_box_p = GTK_BOX(gtk_hbox_new(false, 2));
@@ -2525,7 +2540,11 @@ void SettingsDialog::read_config(bool search_localfile) {
 	
 	  // look for "RINGS:"
 	  else if (get_prog_parm("RINGS:", file_read, result)) {
-	    modem_page.set_rings(result);
+	    if (std::atoi(result.c_str()) < 1
+		|| std::atoi(result.c_str()) > 9) {
+	      modem_page.set_rings("1");
+	    }
+	    else modem_page.set_rings(result);
 	  }
 	
 	  // look for "DIALMODE:"
@@ -2560,7 +2579,11 @@ void SettingsDialog::read_config(bool search_localfile) {
 
 	  // look for "PRINT_SHRINK:"
 	  else if (get_prog_parm("PRINT_SHRINK:", file_read, result)) {
-	    print_page.set_shrink(result);
+	    if (std::atoi(result.c_str()) < 50
+		|| std::atoi(result.c_str()) > 100) {
+	      print_page.set_shrink("100");
+	    }
+	    else print_page.set_shrink(result);
 	  }
 
 	  // look for "PRINT_POPUP:"
@@ -2585,7 +2608,11 @@ void SettingsDialog::read_config(bool search_localfile) {
 
 	  // look for "SOCK_SERVER_PORT:"
 	  else if (get_prog_parm("SOCK_SERVER_PORT:", file_read, result)) {
-	    sock_page.set_port(result);
+	    if (std::atoi(result.c_str()) < 1024
+		|| std::atoi(result.c_str()) > 65535) {
+	      sock_page.set_port("9900");
+	    }
+	    else sock_page.set_port(result);
 	  }
 
 	  // look for "SOCK_CLIENT_ADDRESS:"
