@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -66,7 +66,7 @@ class ModemPage: public MainWidgetBase {
   GtkWidget* device_entry_p;
   GtkWidget* lock_entry_p;
   GtkWidget* capabilities_entry_p;
-  GtkWidget* rings_entry_p;
+  GtkWidget* rings_spin_button_p;
   GtkWidget* auto_button_p;
   GtkWidget* class1_button_p;
   GtkWidget* class2_button_p;
@@ -141,7 +141,7 @@ class PrintPage: public MainWidgetBase {
   PrintMessages help_messages;
 
   GtkWidget* command_entry_p;
-  GtkWidget* shrink_entry_p;
+  GtkWidget* shrink_spin_button_p;
   GtkWidget* popup_check_button_p;
   GtkWidget* command_help_button_p;
   GtkWidget* shrink_help_button_p;
@@ -195,7 +195,7 @@ class SockPage: public MainWidgetBase {
   GtkWidget* popup_button_p;
   GtkWidget* localhost_button_p;
   GtkWidget* other_address_button_p;
-  GtkWidget* port_entry_p;
+  GtkWidget* port_spin_button_p;
   GtkWidget* other_addresses_entry_p;
   GtkWidget* run_server_help_button_p;
   GtkWidget* popup_help_button_p;
