@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 2002 and 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -171,7 +171,7 @@ SockMessages::SockMessages(void): SettingsMessagesBase(client_address + 1) {
   captions[popup] = gettext("efax-gtk help: Popup");
 
   messages[port] = gettext("This specifies the port number on which the socket server is to "
-			   "listen.");
+			   "listen.  It should be between 1024 and 65535.");
   captions[port] = gettext("efax-gtk help: Port");
 
   messages[client_address] = gettext("This determines whether addresses other than localhost and your machine's own "
