@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 to 2005 Chris Vine
+/* Copyright (C) 2001 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -39,6 +39,10 @@ COPYING distributed with the source files.
 #include "socket_list_icons.h"
 #include "utils/utf8_utils.h"
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
 #ifdef HAVE_STRINGSTREAM
 #include <sstream>
 #else
@@ -300,7 +304,7 @@ void SocketListDialog::set_socket_list_rows(std::pair<SharedPtr<FilenamesList>,
     // filenames_iter->first will contain the temporary file name created by mkstemp
     // in void SocketServer::accept_client()
     // filenames_iter->second will contain the print job number assigned by
-    // Socket_serve::add_file()
+    // SocketServer::add_file()
 
     // get a row to insert the file name in
     GtkTreeIter row_iter;
@@ -342,7 +346,7 @@ std::pair<const char*, char* const*> SocketListDialog::get_view_file_parms(const
     view_cmd = Utf8::filename_from_utf8(prog_config.ps_view_cmd);
   }
   catch (Utf8::ConversionError&) {
-    write_error("UTF-8 conversion error in SocketListDialog::view_file()\n");
+    write_error("UTF-8 conversion error in SocketListDialog::get_view_file_parms()\n");
     return std::pair<const char*, char* const*>(0,0);
   }
   
@@ -505,11 +509,15 @@ void SocketListDialog::remove_file(void) {
     // in a GcharScopedHandle object so we need to free it by hand
     g_free(file_name_p);
 
-    // the last call will cause the SocketServer object to invoke
-    // SocketServer::filelist_changed_notify Notifier object
-    // which will in turn cause the MainWindow object to invoke
-    // set_socket_list_rows() above and so refresh the socket file
-    // list. The server object will also clean up by deleting the temporary
-    // file it created.  We do not need to do anything else here.
+    // the emission of the remove_from_socket_server_filelist signal
+    // will invoke MainWindow::remove_from_socket_server_filelist()
+    // which will call SocketServer::remove_file() which will then
+    // invoke the SocketServer::filelist_changed_notify Notifier
+    // object which will in turn invoke the
+    // MainWindow::socket_filelist_changed_notify_slot() which will
+    // then call SocketListDialog::set_socket_list_rows() and so
+    // refresh the socket file list.  The server object will also
+    // clean up by deleting the temporary file it created.  We do not
+    // therefore need to do anything else here.
   }
 }
