@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 and 2005 Chris Vine
+/* Copyright (C) 2004 and 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -18,6 +18,10 @@ COPYING distributed with the source files.
 #include "addressbook.h"
 #include "socket_notify.h"
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
 #ifdef HAVE_STRINGSTREAM
 #include <sstream>
 #else
