@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 to 2005 Chris Vine
+/* Copyright (C) 2003 to 2006 Chris Vine
 
 This program is distributed under the General Public Licence, version 2.
 For particulars of this and relevant disclaimers see the file
@@ -25,6 +25,10 @@ COPYING distributed with the source files.
 #include "socket_server.h"
 #include "utils/shared_handle.h"
 
+#ifdef HAVE_OSTREAM
+#include <ostream>
+#endif
+
 #ifdef ENABLE_NLS
 #include <libintl.h>
 #endif
@@ -38,6 +42,7 @@ SocketServer::SocketServer(void): server_running(false),
 				  serve_sock_fd(-1), count (0),
                                   working_dir(prog_config.working_dir),
 				  filenames_s(new(FilenamesList)) {
+
   // we have included std::string working_dir member so that we can access it in the
   // socket server thread created by SocketServer::start() without having to
   // introduce locking of accesses to prog_config.working_dir by the main GUI thread
@@ -257,19 +262,35 @@ void SocketServer::read_socket(int file_fd, int connect_sock_fd, const char* fil
 
 void SocketServer::stop(void) {
 
+  // this should only be run in the main GUI thread - check (we can
+  // use any convenient Notifier object for this)
+  if (!socket_error_notify.in_main_thread()) {
+    write_error("Call to SocketServer::stop() in other than the main thread\n");
+    return;
+  }
+
   if (server_running) {
     socket_thread_h->cancel();
-    socket_thread_h->join();
-
-    // this method is running in the main GUI thread so use stdout_message directly
-    stdout_message("Closing the socket\n");
-
     cleanup();
   }
 }
 
 void SocketServer::cleanup(void) {
 
+  // this should only be run in the main GUI thread, either by a call
+  // by the Notifier object socket_error_notify or by a call from
+  // SocketServer::stop() - check (we can use any convenient Notifier
+  // object for this)
+  if (!socket_error_notify.in_main_thread()) {
+    write_error("Call to SocketServer::cleanup() in other than the main thread\n");
+    return;
+  }
+
+  socket_thread_h->join();
+
+  // this method is running in the main GUI thread so use stdout_message directly
+  stdout_message(gettext("Closing the socket\n"));
+
   if (serve_sock_fd >= 0) {
     shutdown(serve_sock_fd, SHUT_RDWR);
     while (close(serve_sock_fd) == -1 && errno == EINTR);
@@ -316,23 +337,28 @@ std::pair<std::string, unsigned int> SocketServer::get_fax_to_send(void) {
 
 int SocketServer::remove_file(const std::string& filename) {
 
-  Thread::Mutex::Lock lock(filenames_mutex);
-
   int return_val = 0;
-  FilenamesList::iterator iter;
   bool found_file = false;
-  for (iter = filenames_s->begin(); !found_file && iter != filenames_s->end(); ++iter) {
-    if (iter->first == filename) {
-      filenames_s->erase(iter);
-      found_file = true;
-      filelist_changed_notify();
-      // clean up by deleting the temporary file we created earlier
-      // in accept_on_client() above
-      unlink(filename.c_str());
+  { // mutex lock scope block
+    Thread::Mutex::Lock lock(filenames_mutex);
+    FilenamesList::iterator iter;
+    for (iter = filenames_s->begin(); !found_file && iter != filenames_s->end(); ++iter) {
+      if (iter->first == filename) {
+	filenames_s->erase(iter);
+	found_file = true;
+      }
     }
-  }
+  } // end of mutex lock scope block
   if (!found_file) return_val = -1;
-  else save_queued_faxes();
+  else {
+    // update the display in any socket list object
+    filelist_changed_notify();
+    // clean up by deleting the temporary file we created earlier
+    // in accept_on_client() above
+    unlink(filename.c_str());
+    // write out the new list of queued fax files
+    save_queued_faxes();
+  }
   return return_val;
 }
 
@@ -410,6 +436,14 @@ void SocketServer::save_queued_faxes(void) {
 
 void SocketServer::write_stdout_from_thread(const char* message) {
 
+  // this should only be run in a thread other than the main GUI thread, or
+  // we can have deadlocks - check
+  if (stdout_notify.in_main_thread()) {
+    write_error("Call to SocketServer::write_stdout_from_thread() from "
+		"the main GUI thread\n");
+    return;
+  }
+
   Thread::Mutex::Lock lock(stdout_mutex);
 
   // use a Thread::Cond object to avoid overwriting an earlier message
@@ -480,6 +514,7 @@ bool SocketServer::is_valid_peer(const sockaddr_in& address) {
     }
 
     // and now add the permitted clients from the settings dialog
+
     // lock the Prog_config object to stop it being modified or accessed in the initial
     // (GUI) thread while we are accessing it here
     Thread::Mutex::Lock lock(*prog_config.mutex_p);
